"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generatePackageJson = void 0;
const devkit_1 = require("@nrwl/devkit");
const project_graph_1 = require("@nrwl/workspace/src/core/project-graph");
const create_package_json_1 = require("@nrwl/workspace/src/utilities/create-package-json");
const fileutils_1 = require("@nrwl/workspace/src/utils/fileutils");
const fs = require("fs");
const path_1 = require("path");
const generatePackageJson = (context, options, outFile) => {
    const { root } = context.workspace.projects[context.projectName];
    const packageJson = (0, create_package_json_1.createPackageJson)(context.projectName, (0, project_graph_1.readCachedProjectGraph)(), {
        root: context.root,
        projectRoot: root
    });
    packageJson.main = options.outputFileName;
    delete packageJson.devDependencies;
    const dependencies = {};
    const buildFile = fs.readFileSync(outFile, 'utf8');
    const re2 = /"(.*)"/gm;
    const externalDependencies = buildFile.match(/require\("(.*?)"\)/gm);
    // Get the package version from the root
    if (externalDependencies) {
        const workspacePackages = (0, devkit_1.readJsonFile)((0, path_1.join)(context.root, 'package.json'));
        const dependenciesName = externalDependencies.map((x) => x.match(re2)[0].replace(/"/gm, ''));
        dependenciesName.forEach((dep) => {
            let depName = dep;
            let packageIsDefined = depName in workspacePackages.dependencies;
            if (!packageIsDefined) {
                if (depName.includes('/')) {
                    depName = depName.split('/').shift();
                    packageIsDefined = depName in workspacePackages.dependencies;
                }
            }
            if (packageIsDefined) {
                dependencies[depName] = workspacePackages.dependencies[depName];
            }
            else {
                console.warn(`Could not add "${dep}", is it added to the package.json?`);
            }
        });
    }
    const projectPackageJson = (0, path_1.join)(root, 'package.json');
    const originalPackageJson = (0, fileutils_1.fileExists)(projectPackageJson)
        ? (0, devkit_1.readJsonFile)(projectPackageJson)
        : { dependencies: {} };
    packageJson.dependencies = Object.assign(Object.assign({}, originalPackageJson.dependencies), dependencies);
    (0, devkit_1.writeJsonFile)(`${options.outputPath}/package.json`, packageJson);
};
exports.generatePackageJson = generatePackageJson;
//# sourceMappingURL=generate-package-json.js.map